Learn R Programming

lawn (version 0.1.7)

lawn_area: Calculate the area of a polygon or group of polygons

Description

Calculate the area of a polygon or group of polygons

Usage

lawn_area(input, lint = FALSE)

Arguments

input
A feature or featurecollection of polygons.
lint
(logical) Lint or not. Uses geojsonhint. Takes up increasing time as the object to get linted increases in size, so probably use by default for small objects, but not for large if you know they are good geojson objects. Default: FALSE

Value

value in square meters

See Also

Other measurements: lawn_along, lawn_bbox_polygon, lawn_bearing, lawn_center, lawn_centroid, lawn_destination, lawn_distance, lawn_envelope, lawn_extent, lawn_line_distance, lawn_midpoint, lawn_point_on_surface, lawn_size, lawn_square

Examples

Run this code
lawn_area(lawn_data$poly)
lawn_area(lawn_data$multipoly)

Run the code above in your browser using DataLab