Learn R Programming

lawn (version 0.6.0)

lawn_average: Average of a field among points within polygons

Description

Calculate the average value of a field for a set of data-Points within a set of data-Polygons

Usage

lawn_average(polygons, points, in_field, out_field = "average", lint = FALSE)

Arguments

in_field

(character) The field in the points feature from which to pull values to average.

out_field

(character) The field in polygons to put results of the averages.

lint

(logical) Lint or not. Uses geojsonhint. Takes up increasing time as the object to get linted increases in size, so probably use by default for small objects, but not for large if you know they are good geojson objects. Default: FALSE

Value

Polygons with the value of out_field set to the calculated averages

See Also

Other aggregations: lawn_collect(), lawn_count(), lawn_deviation(), lawn_max(), lawn_median(), lawn_min(), lawn_sum(), lawn_variance()

Examples

Run this code
# NOT RUN {
# using data in the package
cat(lawn_data$points_average)
cat(lawn_data$polygons_average)
lawn_average(polygons = lawn_data$polygons_average,
             points = lawn_data$points_average, 'population')
# }

Run the code above in your browser using DataLab