powered by
Takes a polygon data-Polygon and returns a bbox
lawn_bbox(x, lint = FALSE)
A FeatureCollection of data-Polygon features.
(logical) Lint or not. Uses geojsonhint. Takes up increasing time as the object to get linted increases in size, so probably use by default for small objects, but not for large if you know they are good geojson objects. Default: FALSE
FALSE
A bounding box.
Other measurements: lawn_along, lawn_area, lawn_bbox_polygon, lawn_bearing, lawn_center_of_mass, lawn_center, lawn_centroid, lawn_destination, lawn_distance, lawn_envelope, lawn_extent, lawn_line_distance, lawn_midpoint, lawn_point_on_surface, lawn_pt2line_distance, lawn_square
lawn_along
lawn_area
lawn_bbox_polygon
lawn_bearing
lawn_center_of_mass
lawn_center
lawn_centroid
lawn_destination
lawn_distance
lawn_envelope
lawn_extent
lawn_line_distance
lawn_midpoint
lawn_point_on_surface
lawn_pt2line_distance
lawn_square
# NOT RUN { bbox <- c(0, 0, 10, 10) lawn_bbox(lawn_bbox_polygon(bbox)) # }
Run the code above in your browser using DataLab