Learn R Programming

lawn (version 0.6.0)

lawn_boolean_clockwise: Boolean clockwise

Description

Boolean clockwise

Usage

lawn_boolean_clockwise(line, lint = FALSE)

Arguments

lint

(logical) Lint or not. Uses geojsonhint. Takes up increasing time as the object to get linted increases in size, so probably use by default for small objects, but not for large if you know they are good geojson objects. Default: FALSE

Value

a logical (TRUE/FALSE)

See Also

Other boolean functions: lawn_boolean_contains(), lawn_boolean_crosses(), lawn_boolean_disjoint(), lawn_boolean_overlap(), lawn_boolean_pointonline(), lawn_boolean_within()

Examples

Run this code
# NOT RUN {
l1 <- '[[0,0],[1,1],[1,0],[0,0]]'
l2 <- '[[0,0],[1,0],[1,1],[0,0]]'
lawn_boolean_clockwise(lawn_linestring(l1))
lawn_boolean_clockwise(lawn_linestring(l2))
# }

Run the code above in your browser using DataLab