Learn R Programming

lawn (version 0.5.0)

lawn_boolean_contains: Boolean contains

Description

Boolean contains

Usage

lawn_boolean_contains(feature1, feature2, lint = FALSE)

Arguments

feature1, feature2
lint

(logical) Lint or not. Uses geojsonhint. Takes up increasing time as the object to get linted increases in size, so probably use by default for small objects, but not for large if you know they are good geojson objects. Default: FALSE

Value

a logical (TRUE/FALSE)

See Also

Other boolean functions: lawn_boolean_clockwise, lawn_boolean_crosses, lawn_boolean_disjoint, lawn_boolean_overlap, lawn_boolean_pointonline, lawn_boolean_within

Examples

Run this code
# NOT RUN {
l1 <- '[[1, 1], [1, 2], [1, 3], [1, 4]]'
pt1 <- '[1, 2]'
lawn_boolean_contains(feature1=lawn_linestring(l1), feature2=lawn_point(pt1))
# }

Run the code above in your browser using DataLab