Learn R Programming

lawn (version 0.1.7)

lawn_center: Get center point

Description

Takes a data-FeatureCollection and returns the absolute center point of all features

Usage

lawn_center(features, lint = FALSE)

Arguments

features
input featurs, as a data-FeatureCollection
lint
(logical) Lint or not. Uses geojsonhint. Takes up increasing time as the object to get linted increases in size, so probably use by default for small objects, but not for large if you know they are good geojson objects. Default: FALSE

Value

a data-Point feature at the absolute center point of all input features

See Also

Other measurements: lawn_along, lawn_area, lawn_bbox_polygon, lawn_bearing, lawn_centroid, lawn_destination, lawn_distance, lawn_envelope, lawn_extent, lawn_line_distance, lawn_midpoint, lawn_point_on_surface, lawn_size, lawn_square

Examples

Run this code
lawn_center(lawn_data$points_average)

Run the code above in your browser using DataLab