Learn R Programming

lawn (version 0.5.0)

lawn_coordall: Get all coordinates from any GeoJSON object, returning an array of coordinate arrays.

Description

Takes any data-GeoJSON and returns an array of coordinate arrays

Usage

lawn_coordall(x, lint = FALSE)

Arguments

x

any data-GeoJSON object

lint

(logical) Lint or not. Uses geojsonhint. Takes up increasing time as the object to get linted increases in size, so probably use by default for small objects, but not for large if you know they are good geojson objects. Default: FALSE

Value

matrix of coordinates, where each row in the matrix is a coordinate pair

Examples

Run this code
# NOT RUN {
lawn_point(c(-74.5, 40)) %>% lawn_coordall()

rings <- list(list(
   c(-2.275543, 53.464547),
   c(-2.275543, 53.489271),
   c(-2.215118, 53.489271),
   c(-2.215118, 53.464547),
   c(-2.275543, 53.464547)
))
lawn_polygon(rings) %>% lawn_coordall()
# }

Run the code above in your browser using DataLab