Learn R Programming

lawn (version 0.6.0)

lawn_count: Count number of points within polygons

Description

Calculates the number of data-Point's that fall within the set of data-Polygon's

Usage

lawn_count(polygons, points, in_field, out_field = "count", lint = FALSE)

Arguments

polygons
in_field

(character) the field in input data to analyze

out_field

(character) the field in which to store results

lint

(logical) Lint or not. Uses geojsonhint. Takes up increasing time as the object to get linted increases in size, so probably use by default for small objects, but not for large if you know they are good geojson objects. Default: FALSE

Value

a data-FeatureCollection

See Also

Other aggregations: lawn_average(), lawn_collect(), lawn_deviation(), lawn_max(), lawn_median(), lawn_min(), lawn_sum(), lawn_variance()

Examples

Run this code
# NOT RUN {
# using data in the package
cat(lawn_data$points_count)
cat(lawn_data$polygons_count)
lawn_count(lawn_data$polygons_count, lawn_data$points_count, 'population')
# }

Run the code above in your browser using DataLab