Learn R Programming

lawn (version 0.1.7)

lawn_data: Data for use in examples

Description

Data for use in examples

Arguments

Format

A list of character strings of points or polygons in FeatureCollection or Feature Geojson formats.

Details

The data objects included in the list, accessible by name
  • filter_features - FeatureCollection of points
  • points_average - FeatureCollection of points
  • polygons_average - FeatureCollection of polygons
  • points_count - FeatureCollection of points
  • polygons_count - FeatureCollection of polygons
  • points_within - FeatureCollection of points
  • polygons_within - FeatureCollection of polygons
  • poly - Feaure of a single 1 degree by 1 degree polygon
  • multipoly - FeatureCollection of two 1 degree by 1 degree polygons
  • polygons_aggregate - FeatureCollection of Polygons from turf.js examples
  • points_aggregate - FeatureCollection of Points from turf.js examples