Character for the name of the field on pts on
which you wish to perform the aggregation.
out_field
Character for the name of the field on the output
polygon FeatureCollection that will store the resultant value.
lint
(logical) Lint or not. Uses geojsonhint. Takes up increasing
time as the object to get linted increases in size, so probably use by
default for small objects, but not for large if you know they are good
geojson objects. Default: FALSE