Learn R Programming

lawn (version 0.6.0)

lawn_kinks: Get points at all self-intersections of a polygon

Description

Get points at all self-intersections of a polygon

Usage

lawn_kinks(input, lint = FALSE)

Arguments

input

Feature of features.

lint

(logical) Lint or not. Uses geojsonhint. Takes up increasing time as the object to get linted increases in size, so probably use by default for small objects, but not for large if you know they are good geojson objects. Default: FALSE

Examples

Run this code
# NOT RUN {
poly <- '{
 "type": "Feature",
 "properties": {},
 "geometry": {
   "type": "Polygon",
   "coordinates": [[
      [-12.034835, 8.901183],
      [-12.060413, 8.899826],
      [-12.03638, 8.873199],
      [-12.059383, 8.871418],
      [-12.034835, 8.901183]
    ]]
  }
}'
lawn_kinks(poly)
# lint input object
# lawn_kinks(poly, TRUE)
# }
# NOT RUN {
poly %>% view
lawn_kinks(poly) %>% view
# }

Run the code above in your browser using DataLab