Learn R Programming

lawn (version 0.5.0)

lawn_line_offset: Offset a linestring

Description

Takes a data-LineString and returns a data-LineString at offset by the specified distance.

Usage

lawn_line_offset(line, distance, units, lint = FALSE)

Arguments

line

Line to measure, a data-LineString.

distance

(integer/numeric) Distance along the line.

units

Can be degrees, radians, miles, kilometers, inches, yards, meters

lint

(logical) Lint or not. Uses geojsonhint. Takes up increasing time as the object to get linted increases in size, so probably use by default for small objects, but not for large if you know they are good geojson objects. Default: FALSE

Value

a data-LineString

Examples

Run this code
# NOT RUN {
line <- '{
  "type": "Feature",
  "properties": {
    "stroke": "#F00"
  },
  "geometry": {
    "type": "LineString",
    "coordinates": [[-83, 30], [-84, 36], [-78, 41]]
  }
}'

lawn_line_offset(line, 2, 'miles')
lawn_line_offset(line, 200, 'miles')
lawn_line_offset(line, 0.5, 'radians')
lawn_line_offset(line, 4, 'yards')


line <- '{
    "type": "LineString",
    "coordinates": [[-83, 30], [-84, 36], [-78, 41]]
}'
lawn_line_offset(line, 4, 'yards')
# }

Run the code above in your browser using DataLab