Learn R Programming

lawn (version 0.6.0)

lawn_line_slice: Slice a line given two points

Description

Takes a line, a start Point, and a stop point and returns the line in between those points

Usage

lawn_line_slice(point1, point2, line, lint = FALSE)

Arguments

point1
point2
line

Line to slice, a data-Feature<(data-LineString)>

lint

(logical) Lint or not. Uses geojsonhint. Takes up increasing time as the object to get linted increases in size, so probably use by default for small objects, but not for large if you know they are good geojson objects. Default: FALSE

Value

A data-Feature<(data-LineString)>

Examples

Run this code
# NOT RUN {
start <- '{
  "type": "Feature",
  "properties": {},
  "geometry": {
    "type": "Point",
    "coordinates": [-77.029609, 38.881946]
  }
}'
stop <- '{
  "type": "Feature",
  "properties": {},
  "geometry": {
    "type": "Point",
    "coordinates": [-77.021884, 38.889563]
  }
}'
line <- '{
 "type": "Feature",
 "properties": {},
 "geometry": {
   "type": "LineString",
   "coordinates": [
     [-77.031669, 38.878605],
     [-77.029609, 38.881946],
     [-77.020339, 38.884084],
     [-77.025661, 38.885821],
     [-77.021884, 38.889563],
     [-77.019824, 38.892368]
    ]
  }
}'
lawn_line_slice(start, stop, line)

# lint input objects
lawn_line_slice(start, stop, line, TRUE)
# }
# NOT RUN {
line %>% view
lawn_line_slice(point1 = start, point2 = stop, line) %>% view
# }

Run the code above in your browser using DataLab