Learn R Programming

lawn (version 0.1.7)

lawn_midpoint: Get a point midway between two points

Description

Takes two data-Point's and returns a point midway between them

Usage

lawn_midpoint(pt1, pt2, lint = FALSE)

Arguments

pt1
First point
pt2
Second point
lint
(logical) Lint or not. Uses geojsonhint. Takes up increasing time as the object to get linted increases in size, so probably use by default for small objects, but not for large if you know they are good geojson objects. Default: FALSE

Value

A data-Point midway between pt1 and pt2

See Also

Other measurements: lawn_along, lawn_area, lawn_bbox_polygon, lawn_bearing, lawn_center, lawn_centroid, lawn_destination, lawn_distance, lawn_envelope, lawn_extent, lawn_line_distance, lawn_point_on_surface, lawn_size, lawn_square

Examples

Run this code
pt1 <- '{
  "type": "Feature",
  "properties": {},
  "geometry": {
    "type": "Point",
    "coordinates": [144.834823, -37.771257]
  }
}'
pt2 <- '{
  "type": "Feature",
  "properties": {},
  "geometry": {
    "type": "Point",
    "coordinates": [145.14244, -37.830937]
  }
}'
lawn_midpoint(pt1, pt2)

Run the code above in your browser using DataLab