powered by
Takes a bounding box and a cell depth and returns a set of square data-Polygon's in a grid.
lawn_square_grid(extent, cellSide, units = "kilometers", mask = NULL)
(numeric) Extent in [minX, minY, maxX, maxY] order.
[minX, minY, maxX, maxY]
(integer) dimension of each cell.
(character) Units to use for cellSide, one of 'miles' or 'kilometers'.
(logical) if passed a Polygon or MultiPolygon, the grid Points will be created only inside it
data-FeatureCollection grid of polygons.
Other interpolation: lawn_hex_grid(), lawn_isolines(), lawn_planepoint(), lawn_point_grid(), lawn_tin(), lawn_triangle_grid()
lawn_hex_grid()
lawn_isolines()
lawn_planepoint()
lawn_point_grid()
lawn_tin()
lawn_triangle_grid()
# NOT RUN { lawn_square_grid(c(-95, 30 ,-85, 40), 30, 'miles') lawn_square_grid(c(-95, 30 ,-85, 40), 10, 'miles') lawn_square_grid(c(-95, 30 ,-85, 40), 3, 'miles') # }
Run the code above in your browser using DataLab