Learn R Programming

lawn (version 0.1.7)

lawn_within: Return points that fall within polygons

Description

Takes a set of data-Point's and a set of data-Polygon's and returns points that fall within the polygons

Usage

lawn_within(points, polygons, lint = FALSE)

Arguments

points
polygons
lint
(logical) Lint or not. Uses geojsonhint. Takes up increasing time as the object to get linted increases in size, so probably use by default for small objects, but not for large if you know they are good geojson objects. Default: FALSE

Value

points that land within at least one polygon, as a data-FeatureCollection

See Also

Other joins: lawn_inside, lawn_tag

Examples

Run this code
cat(lawn_data$points_within)
cat(lawn_data$polygons_within)
lawn_within(lawn_data$points_within, lawn_data$polygons_within)

Run the code above in your browser using DataLab