If there are more than one feature within the featurecollection,
each feature is split out into a separate feature, returned in a list.
Each feature is assigned a class matching it's GeoJSON data type
(e.g., point, polygon, linestring).
See Also
as.feature , which is similarly named, but has a different
purpose