Learn R Programming

lawn (version 0.1.7)

as_feature: Convert a FeatureCollection to a Feature

Description

Convert a FeatureCollection to a Feature

Usage

as_feature(x)

Arguments

Details

If there are more than one feature within the featurecollection, each feature is split out into a separate feature, returned in a list. Each feature is a assigned a class matching it's GeoJSON data type (e.g., point, polygon, linestring).

Examples

Run this code
as_feature(lawn_random())
# as_feature(lawn_random("polygons"))

Run the code above in your browser using DataLab