lawn_area: Calculate the area of a polygon or group of polygons
Description
Calculate the area of a polygon or group of polygons
Usage
lawn_area(input, lint = FALSE)
Arguments
input
A feature or featurecollection of polygons.
lint
(logical) Lint or not. Uses geojsonhint. Takes up increasing time
as the object to get linted increases in size, so probably use by
default for small objects, but not for large if you know they are good geojson
objects. Default: FALSE