Learn R Programming

lawn (version 0.1.7)

lawn_explode: Explode vertices to points

Description

Takes a feature or set of features and returns all positions as points

Usage

lawn_explode(input, lint = FALSE)

Arguments

input
Feature of features
lint
(logical) Lint or not. Uses geojsonhint. Takes up increasing time as the object to get linted increases in size, so probably use by default for small objects, but not for large if you know they are good geojson objects. Default: FALSE

Value

a data-FeatureCollection of points

Examples

Run this code
poly <- '{
 "type": "Feature",
 "properties": {},
 "geometry": {
   "type": "Polygon",
   "coordinates": [[
     [177.434692, -17.77517],
     [177.402076, -17.779093],
     [177.38079, -17.803937],
     [177.40242, -17.826164],
     [177.438468, -17.824857],
     [177.454948, -17.796746],
     [177.434692, -17.77517]
    ]]
 }
}'
lawn_explode(poly)

Run the code above in your browser using DataLab