Learn R Programming

lawn (version 0.1.7)

lawn_simplify: Simplify GeoJSON data

Description

Takes a data-LineString or data-Polygon and returns a simplified version

Usage

lawn_simplify(feature, tolerance = 0.01, high_quality = FALSE, lint = FALSE)

Arguments

feature
a data-LineString or data-Polygon feature to be simplified
tolerance
(numeric) Simplification tolerance
high_quality
(boolean) Whether or not to spend more time to create a higher-quality simplification with a different algorithm. Default: FALSE
lint
(logical) Lint or not. Uses geojsonhint. Takes up increasing time as the object to get linted increases in size, so probably use by default for small objects, but not for large if you know they are good geojson objects. Default: FALSE

Value

a simplified featureA Feature of either data-Polygon or data-LineString

Details

Internally uses simplify-js (http://mourner.github.io/simplify-js/) to perform simplification.

See Also

Other transformations: lawn_bezier, lawn_buffer, lawn_concave, lawn_convex, lawn_erase, lawn_intersect, lawn_merge, lawn_union

Examples

Run this code
feature <- '{
  "type": "Feature",
  "properties": {},
  "geometry": {
    "type": "Polygon",
    "coordinates": [[
      [-70.603637, -33.399918],
      [-70.614624, -33.395332],
      [-70.639343, -33.392466],
      [-70.659942, -33.394759],
      [-70.683975, -33.404504],
      [-70.697021, -33.419406],
      [-70.701141, -33.434306],
      [-70.700454, -33.446339],
      [-70.694274, -33.458369],
      [-70.682601, -33.465816],
      [-70.668869, -33.472117],
      [-70.646209, -33.473835],
      [-70.624923, -33.472117],
      [-70.609817, -33.468107],
      [-70.595397, -33.458369],
      [-70.587158, -33.442901],
      [-70.587158, -33.426283],
      [-70.590591, -33.414248],
      [-70.594711, -33.406224],
      [-70.603637, -33.399918]
    ]]
  }
}'

lawn_simplify(feature, tolerance = 0.01)

Run the code above in your browser using DataLab