Learn R Programming

lawn (version 0.1.7)

lawn_square: Calculate a square bounding box

Description

Takes a bounding box and calculates the minimum square bounding box that would contain the input.

Usage

lawn_square(bbox)

Arguments

bbox
A bounding box

Value

A square surrounding bbox, numeric vector of length four

See Also

Other measurements: lawn_along, lawn_area, lawn_bbox_polygon, lawn_bearing, lawn_center, lawn_centroid, lawn_destination, lawn_distance, lawn_envelope, lawn_extent, lawn_line_distance, lawn_midpoint, lawn_point_on_surface, lawn_size

Examples

Run this code
bbox <- c(-20, -20, -15, 0)
lawn_square(bbox)

Run the code above in your browser using DataLab